####Egg ratio method for production
counts=read.csv("ZoopCountAverages2011.csv")
lengths=read.csv("ZoopLengths2011.csv")
LWregressions=read.csv("LWregressions2.csv")

daphniaCounts=counts[counts$taxa=="Daphnia",]
daphniaLengths=lengths[lengths$taxa=="Daphnia",]
uniqueID=paste(daphniaLengths$lake,daphniaLengths$date,sep="")
daphniaLengths$uniqueID=uniqueID

#calculate mean brood size for each date
MBS=tapply(daphniaLengths$Eggs,daphniaLengths$uniqueID,mean,na.rm=TRUE)
daphniaCounts=daphniaCounts[-c(13,26),]
MBS[c(3,4,5,6,7,15,16,18,20,21)]=1
daphniaCounts$MBS=MBS

#calculate reproductive ratio (RR)
FWB=tapply(daphniaLengths$Eggs,daphniaLengths$uniqueID,function(daphniaLengths) sum(!is.na(daphniaLengths)))
FWB[c(3,4,5,6,7,15,16,18,20,21)]=1
RR=FWB/daphniaCounts$counts
daphniaCounts$RR=RR

#calculate egg ratio (Ea)
Ea=daphniaCounts$MBS*daphniaCounts$RR
daphniaCounts$Ea=Ea

#calculate egg development time (D)
#using equation from Lei and Armitage 1980
#lnD=3.4898-0.1796T+00024T^2
D6=3.4898-0.1796*6+0.0024*6^2
D6=exp(D6)
temps=read.csv("2011Limnodata.csv")
temps=temps[temps$Lake==c("EL","WL"),]
uniqueID=paste(temps$Lake,temps$Date,sep="")
temps$uniqueID=uniqueID
uniques=unique(temps$Depth)
Temp=tapply(temps$Temp_degreesC,temps$uniqueID,mean,na.rm=TRUE)
Temp=Temp[-c(13,14,27)]
D=3.4898-0.1796*Temp+0.0024*Temp^2
D=exp(D)
daphniaCounts$D=D
b=(log(daphniaCounts$Ea+1))/daphniaCounts$D
daphniaCounts$b=b
countsPerM2=(daphniaCounts$counts/2)/0.07297
daphniaCounts$countsPerM2=countsPerM2

#calculate mass and production
mass=c()
for(i in 1:nrow(daphniaLengths)){
	rowi=match(daphniaLengths$taxa[i],LWregressions$taxa)
	mass[i]=exp(LWregressions$b[rowi]+(LWregressions$m[rowi]*(log(daphniaLengths$length[i]))))
	}
daphniaLengths$mass=mass
masses=tapply(daphniaLengths$mass,daphniaLengths$uniqueID,mean)
totalMass=daphniaCounts$countsPerM2*masses
daphniaCounts$totalMass=totalMass
daphniaCounts$avgmass=masses
Production=daphniaCounts$b*daphniaCounts$totalMass
Productiong=Production/10^6
mean(daphniaCounts$Production_g[daphniaCounts$lake=="EL"])*365
mean(daphniaCounts$Production_g[daphniaCounts$lake=="WL"])*365

####
ELdaphnia=daphniaCounts[daphniaCounts$lake=="EL",]
ELr=c()
for(i in 1:nrow(ELdaphnia)){
	R=(log(ELdaphnia$countsPerM2[i+1]/ELdaphnia$countsPerM2[i]))/7
	ELr[i]=R
	}
ELB=(ELdaphnia$b/ELr)*(ELdaphnia$countsPerM2)*(exp(ELr*7)-1)
ELProd=ELB*(ELdaphnia$avgmass*10^-6)
mean(ELProd,na.rm=TRUE)


WLdaphnia=daphniaCounts[daphniaCounts$lake=="WL",]
WLr=c()
for(i in 1:nrow(WLdaphnia)){
	R=(log(WLdaphnia$countsPerM2[i+1]/WLdaphnia$countsPerM2[i]))/7
	WLr[i]=R
	}
WLB=(WLdaphnia$b/WLr)*(WLdaphnia$counts)*(exp(WLr*7)-1)
WLProd=WLB*(mean(WLdaphnia$avgmass*10^-6))
mean(WLProd,na.rm=TRUE)